#!/bin/bash
# version 2001
# 2022-06-02 Add check tool dependencies

#### Start: Failures
failures()
{
case "$1" in
    0) echo "$(tput setaf 2)prn-session.sh finished with success$(tput sgr0)" ;;
    1) echo echo "$(tput setaf 1)Failed to execute $(tput sgr0)" ; exit 1 ;;
    4) echo "$(tput setaf 5)Follow the instructions above $(tput sgr0)" ; exit 4 ;;
esac
}
#### End: Failures
#Start: Check if tools are installed
#Start: Check rlwrap
check_rlwrap()
{
if ! type rlwrap > /dev/null; then
  echo "$(tput setaf 1)Missing 'rlwrap' which is important to run this script"
  echo "install it with the command $(tput setaf 2)'sudo apt-get install rlwrap'.$(tput sgr0)"
  #sudo apt-get update && apt-get install rlwrap
  failures 4
#else
#    echo "$(tput setaf 2)Found 'rlwrap'$(tput sgr0)"
fi
}
#End: Check rlwrap
#Start: Check socat
check_socat()
{
if ! type socat > /dev/null; then
  echo "$(tput setaf 1)Missing 'socat' which is important to run this script"
  echo "install it with the command $(tput setaf 2)'sudo apt-get install socat'.$(tput sgr0)"
  #sudo apt-get update && apt-get install socat
  failures 4
#else
#  echo "$(tput setaf 2)Found 'socat'$(tput sgr0)"
fi
}
#End: Check expect
#Start: Check expect
check_expect()
{
if ! type expect > /dev/null; then
  echo "$(tput setaf 1)Missing 'expect' which is important to run this script"
  echo "install it with the command $(tput setaf 2)'sudo apt-get install expect'.$(tput sgr0)"
  #sudo apt-get update && apt-get install expect
  failures 4
#else
#    echo "$(tput setaf 2)Found 'expect'$(tput sgr0)"
fi
}
#End: Check expect
#Start: Check expect
check_moreutils()
{
if ! type ts > /dev/null; then
  echo "$(tput setaf 1)Missing 'moreutils' which is important to run this script"
  echo "install it with the command $(tput setaf 2)'sudo apt-get install moreutils'.$(tput sgr0)"
  #sudo apt-get update && apt-get install moreutils
  failures 4
#else
#  echo "$(tput setaf 2)Found 'moreutils'$(tput sgr0)"
fi
}
#End: Check moreutils
# Start: Check python ... needed to plot
check_python()
{
if ! type python > /dev/null; then
  echo "$(tput setaf 1)Missing 'python' which is important to run this script"
  echo "install it with the command $(tput setaf 2)'sudo apt-get install python-is-python3'."
  #sudo apt-get update && apt-get install python-is-python3s
  failures 4
fi
}

# End: Check python ... nneeded to plot
check_rlwrap
check_socat
check_expect
check_moreutils
check_python

#End: Check if tools are installed
timestamp=$(date +%Y%m%d_%H%M%S)
log=${1}
if [ -z "$log" ]; then
  echo "Usage: $0 <text>_log.txt [device] <description>"
  echo "Example: $0 FW3111-5508_MMU2019-638_MMU-Dice_log.txt /dev/ttyAMC0 'Testing FW3.11.1-RC-5508 MMU2SR2.0.19-638 with MMU Dice'"
  sleep 10
  log="Empty_log"
fi  
log_prefix=${log%%_log.*}
dev=${2:-/dev/ttyAMC0}
if [ -z "$SN" ]; then
  #SN=$(udevadm info --query all --name $dev --attribute-walk|grep "CZPX"|cut -d '"' -f2)
  SN=$(udevadm info --query all --name $dev --attribute-walk | grep -A27 '{idVendor}=="2c99"'| grep "serial" |cut -d '"' -f2)
fi
description=${3}
if [ -z "$description" ]; then
  description="No description"
fi  

rate=115200
if [ ! -d "Logs" ]; then
  mkdir Logs
fi 
logpath="Logs/"
logfilename="${logpath}${timestamp}_SN-${SN}-${log}"
dscfilename="${logpath}${timestamp}_SN-${SN}-${log_prefix}_dsc.txt"

echo $SN >$dscfilename
echo $description >>$dscfilename  
#show settings and arguments
echo
echo "Script: $script"
echo "Log:    $logfilename"
echo "Desc:   $3"
echo "DSC-fn: $dscfilename"
echo "Port:   $dev"
echo "Baud:   $rate"
echo "SN:     $SN"
echo

if [ -z "$logfilename" ]; then
  echo "Usage: $0 <log> [device] <description>"
  exit 2
fi

{ rlwrap -a -S '> ' tee >(sed -ue 's/^/SEND /' >&2) \
  | socat - "$dev,b$rate,cfmakeraw" | sed -ue 's/^/RECV /'
} 2>&1 | ts '[%Y-%m-%d %H:%M:%.S]' | tee "$logfilename"

#socat - "$dev,b$rate,cfmakeraw"

